Datasets | Description |
--- | --- | ---

### New Dataset

Name
Description
Creation date

##### Columns

Name | Type | Tags |
--- | --- | --- | ---

##### Keys |

Primary | None Click on the keys right to the column names (Warning: order is important)
Foreigns |

##### Columns

Name | Type | Tags
--- | --- | ---

##### Keys |

Primary | None Click on the keys right to the column names (Warning: order is important)
Foreigns |

### Foreign Key Definition

Reference

### Dataset Name

### Upload Data into ...

#### Expected columns

#### Select a file

### Date Format

### Alert Title

Alert Text

### Progress bar Title

### Alert Title

Alert Text

### Alert Title

Alert Text

### Info Title

Info Text

### New tag